@@ -11,10 +11,12 @@ Exsample::
 import logging
 from .namespace import NS, NT
 import datetime
+import atexit
+
 # from .endpoints import Dtalk
 
 __all__ = [
-    'log', 'warn', 'debug',  'bus'
+    'log', 'warn', 'debug', 'bus',
 ]
 
 warn = NS('warn')
@@ -26,9 +28,10 @@ def log_print(x):
         # from termcolor import cprint
         # _log_print = (lambda x: cprint(x, 'red', 'on_cyan'))@P
         # str(datetime.datetime.now()) + ':' + str(x) >> _log_print
-        from rich.console import Console
-        console = Console()
-        console.log(x, log_locals=False)
+        # from rich.console import Console
+        # console = Console()
+        # console.log(x, log_locals=False)
+        print(datetime.datetime.now(), ':', x)
     except:
         print(datetime.datetime.now(), ':', x)
 
@@ -39,6 +42,22 @@ log.sink(log_print)
 
 bus = NT('bus')
 
+
+@atexit.register
+def exit():
+    """进程退出时发信号到log.
+
+    Examples:
+    ----------
+    when('exit',source=log).then(lambda :print('bye bye'))
+    """
+    #
+    try:
+        bus.stop()
+    except Exception as e:
+        e >> log
+
+
 debug = NS('debug')
 # debug.map(str).unique() >> Dtalk()
 # debug.sink(lambda x: console.log(x, log_locals=True))
