@@ -422,7 +422,19 @@ class Stream(object):
             sync(self.loop, _)
 
     def update(self, x, who=None):
-        self._emit(x)
+        try:
+            if isinstance(x, gen.Awaitable):
+                futs = gen.convert_yielded(x)
+                if not self.loop:
+                    self._set_asynchronous(False)
+                if self.loop is None and self.asynchronous is not None:
+                    self._set_loop(get_io_loop(self.asynchronous))
+                self.loop.add_future(futs, lambda x: self._emit(x.result()))
+            else:
+                return self._emit(x)
+        except Exception as e:
+            logger.exception(e)
+            raise
 
     def gather(self):
         """ This is a no-op for core streamz
@@ -767,11 +779,26 @@ class sink(Sink):
         super().__init__(upstream, **stream_kwargs)
 
     def update(self, x, who=None, metadata=None):
-        result = self.func(x, *self.args, **self.kwargs)
-        if gen.isawaitable(result):
-            return result
-        else:
-            return []
+        # result = self.func(x, *self.args, **self.kwargs)
+        # if gen.isawaitable(result):
+        #     return result
+        # else:
+        #     return []
+
+        try:
+            result = self.func(x, *self.args, **self.kwargs)
+            if isinstance(result, gen.Awaitable):
+                futs = gen.convert_yielded(result)
+                if not self.loop:
+                    self._set_asynchronous(False)
+                if self.loop is None and self.asynchronous is not None:
+                    self._set_loop(get_io_loop(self.asynchronous))
+                self.loop.add_future(futs, lambda x: self._emit(x.result()))
+            else:
+                return self._emit(result)
+        except Exception as e:
+            logger.exception(e)
+            raise
 
     def destroy(self):
         super().destroy()
@@ -856,11 +883,18 @@ class map(Stream):
     def update(self, x, who=None):
         try:
             result = self.func(x, *self.args, **self.kwargs)
+            if isinstance(result, gen.Awaitable):
+                futs = gen.convert_yielded(result)
+                if not self.loop:
+                    self._set_asynchronous(False)
+                if self.loop is None and self.asynchronous is not None:
+                    self._set_loop(get_io_loop(self.asynchronous))
+                self.loop.add_future(futs, lambda x: self._emit(x.result()))
+            else:
+                return self._emit(result)
         except Exception as e:
             logger.exception(e)
             raise
-        else:
-            return self._emit(result)
 
 
 @Stream.register_api()
@@ -1096,6 +1130,21 @@ class http(Stream):
 
     x = httpx
 
+    @classmethod
+    async def get_web_article(cls, url, key='text'):
+        """
+        提取网页信息，key为可选项：title｜description｜image|text 等,默认返回dict
+        http.get_web_article(url,'text')>>print
+        """
+        from trafilatura import bare_extraction
+
+        response = await httpx(url)
+        data = bare_extraction(response.content)
+        if key:
+            return data.get(key)
+        else:
+            return data
+
 
 def sync(loop, func, *args, **kwargs):
     """
