@@ -35,7 +35,8 @@ import tornado.web
 import tornado.wsgi
 import contextlib
 from functools import partial
-from werkzeug.routing import Map, Rule, _rule_re
+from werkzeug.routing import Map, Rule
+import re
 import os
 import inspect
 from werkzeug.local import LocalStack, LocalProxy
@@ -48,7 +49,7 @@ from sockjs.tornado import SockJSRouter, SockJSConnection
 import json
 from tornado import gen
 from .core import Stream
-from .bus import log
+from .bus import log, bus
 from .pipe import ls
 import datetime
 from .namespace import NW
@@ -69,6 +70,22 @@ except Exception:
     pass
 
 
+_rule_re = re.compile(
+    r"""
+    (?P<static>[^<]*)                           # static rule data
+    <
+    (?:
+        (?P<converter>[a-zA-Z_][a-zA-Z0-9_]*)   # converter name
+        (?:\((?P<args>.*?)\))?                  # converter arguments
+        \:                                      # variable delimiter
+    )?
+    (?P<variable>[a-zA-Z_][a-zA-Z0-9_]*)        # variable name
+    >
+    """,
+    re.VERBOSE,
+)
+
+
 def _lookup_handler_object(name):
     top = _handler_ctx_stack.top
     if top is None:
@@ -343,8 +360,7 @@ class Page(object):
 
     def route_(self, rule, methods=None, werkzeug_route=None,
                tornado_route=None, handler_bases=None, fn=None, nowrap=None):
-        if not methods:
-            methods = ['GET']
+        methods = methods or ['GET']
 
         clsname = '%sHandler' % fn.__name__.capitalize()
         # TODO: things get complicated if you use your own base class and debug=True
@@ -423,7 +439,7 @@ class Page(object):
         if use_werkzeug_route:
             r = Rule(rule, methods=methods)
             self.url_map.add(r)
-            r.compile()
+            # r.compile()
             pattern = r._regex.pattern.replace('^\\|', "")
             self.registery[pattern] = klass
         else:
@@ -434,9 +450,7 @@ class Page(object):
 
     def run(self, port=9999, host="127.0.0.1", **settings):
         self.debug = settings.get('debug', False)
-        template_path = settings.get('template_path')
-        if not template_path:
-            settings['template_path'] = self.template_path
+        settings['template_path'] = settings.get('template_path') or self.template_path
         if self.debug:
             if with_wsgi_adapter:
                 import tornado.httpserver
@@ -536,7 +550,7 @@ page = Page()
 class PageServer(object):
     page = page
 
-    def __init__(self, name='default', host='127.0.0.1', port=9999, start=False):
+    def __init__(self, name='default', host='127.0.0.1', port=9999, start=False, **kwargs):
         self.name = name
         self.page = page
         self.port = port
@@ -546,7 +560,8 @@ class PageServer(object):
         self.StreamRouter = SockJSRouter(StreamsConnection, r'')
         self.application = tornado.web.Application(
             self.page.get_routes() +
-            self.StreamRouter.urls
+            self.StreamRouter.urls,
+            **kwargs
         )
         if start:
             self.start()
@@ -558,15 +573,13 @@ class PageServer(object):
         self.server = self.application.listen(self.port)
         os.system(f'open http://{self.host}:{self.port}/')
 
-    def close(self):
-        self.server.close()
+    def stop(self):
+        self.server.stop()
 
 
 def webview(s, url='/', server=None):
-    if not url.startswith('/'):
-        url = '/'+url
-    if not server:
-        server = NW('stream_webview')
+    url = url if url.startswith('/') else '/'+url
+    server = server or NW('stream_webview')
     server.streams[url].append(s)
 
     page.route(url)(lambda: render_template(
@@ -574,6 +587,7 @@ def webview(s, url='/', server=None):
     server.add_page(page)
     print('start webview:', 'http://'+server.host+':'+str(server.port)+url)
     print('with these streams:', server.streams[url])
+    return server
 
 
 Stream.webview = webview
